@@ -1,4 +1,5 @@
 import getpass
+import os
 import sys
 from abc import ABC
 from argparse import ArgumentParser
@@ -32,7 +33,8 @@ class CronCommand(CommandBase, ABC):
     def setup_task(self):
         cron = self.remove_task(partial=True)
 
-        job = cron.new(command=f'{sys.executable} {self.runner_path} {self.name}', comment=self.comment)
+        executable = os.path.join(os.path.dirname(sys.executable), 'dtrun')
+        job = cron.new(command=f'cd {self.root} && {executable} {self.name}', comment=self.comment)
         job.setall(self.schedule)
         job.enable()
         cron.write()
